Enum HDKeyRef
Source pub enum HDKeyRef<'a> {
MasterKey(MasterKey),
DerivedKey(DerivedKeyRef<'a>),
}
HD Key (non owned, zero copy).
The CBOR tag used when HDKeyRef is embedded in other CBOR types.
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Decode a value using the given
Decoder.
Read more
If possible, return a nil value of
Self.
Read more
Encode a value of this type using the given
Encoder.
Read more
SourceAvailable on crate feature alloc only.
Converts to this type from the input type.
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
SourceAvailable on crate feature bitcoin only.
The type returned in the event of a conversion error.
Performs the conversion.
SourceAvailable on crate feature bitcoin only.
The type returned in the event of a conversion error.
Performs the conversion.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.