pub struct Keypath {
pub components: Vec<PathComponent>,
pub source_fingerprint: Option<NonZeroU32>,
pub depth: Option<u8>,
}Expand description
Metadata for the complete or partial derivation path of a key.
Fields
components: Vec<PathComponent>Path component.
source_fingerprint: Option<NonZeroU32>Fingerprint from the ancestor key.
depth: Option<u8>How many derivations this key is from the master (which is 0).