pub struct KeypathRef<'a> {
pub components: PathComponents<'a>,
pub source_fingerprint: Option<NonZeroU32>,
pub depth: Option<u8>,
}Expand description
Metadata for the complete or partial derivation path of a key (non-owned, zero copy).
Fields
components: PathComponents<'a>Path component.
source_fingerprint: Option<NonZeroU32>Fingerprint from the ancestor key.
depth: Option<u8>How many derivations this key is from the master (which is 0).
Implementations
Sourceimpl<'a> KeypathRef<'a>
impl<'a> KeypathRef<'a>
Sourcepub fn new_master(source_fingerprint: NonZeroU32) -> Self
pub fn new_master(source_fingerprint: NonZeroU32) -> Self
Create a new key path for a master extended public key.
The source_fingerprint parameter is the fingerprint of the master key.