Value

Enum Value 

pub enum Value<'a> {
    Bytes(&'a [u8]),
    HDKey(HDKeyRef<'a>),
    Psbt(&'a [u8]),
    PassportRequest(PassportRequest),
    PassportResponse(PassportResponse<'a>),
}

Variants



Bytes(&'a [u8])

bytes.



HDKey(HDKeyRef<'a>)

crypto-hdkey.



Psbt(&'a [u8])

crypto-psbt.



PassportRequest(PassportRequest)

crypto-request for Passport.



PassportResponse(PassportResponse<'a>)

crypto-response for Passport.

Implementations

Source

impl<'a> Value<'a>

pub fn from_ur(ur_type: &str, payload: &'a [u8]) -> Result<Self, Error>

Construct a new Value from the type and the CBOR payload.

pub fn ur_type(&self) -> &'static str

Return the type of this value as a string.

Notes

This will return the deprecated types as some implementers of UR still don’t support the newer ones.

When changing this to use the newer types also change Value::from_ur.